@@ -166,7 +166,10 @@ class TestBOM(TransactionTestCase):
     def test_export_parts(self):
         (p1, p2, p3, p4) = create_some_fake_parts(organization=self.organization)
 
-        response = self.client.post(reverse('bom:home'), {'download': ''}, follow=True)
+        response = self.client.get(reverse('bom:home'), {'download': ''}, follow=True)
+        self.assertEqual(response.status_code, 200)
+
+        response = self.client.get(reverse('bom:home'), {'download': f'{p1.id}'}, follow=True)
         self.assertEqual(response.status_code, 200)
 
     def test_part_upload_bom(self):
@@ -601,6 +604,17 @@ class TestBOM(TransactionTestCase):
         for msg in messages:
             self.assertEqual(msg.tags, 'error')
 
+    def test_upload_part_with_sellers(self):
+        create_some_fake_part_classes(self.organization)
+        # Should pass
+        initial_parts_count = Part.objects.all().count()
+        with open('bom/test_files/test_new_parts_sellers.csv') as test_csv:
+            response = self.client.post(reverse('bom:upload-parts'), {'file': test_csv})
+        self.assertEqual(response.status_code, 302)
+
+        parts_count = Part.objects.all().count()
+        self.assertEqual(parts_count - initial_parts_count, 4)
+
     def test_upload_part_classes(self):
         # Should pass
         with open(f'{TEST_FILES_DIR}/test_part_classes.csv') as test_csv:
@@ -743,9 +757,7 @@ class TestBOM(TransactionTestCase):
             'ncnr': True,
         }
 
-        response = self.client.post(reverse('bom:sellerpart-edit', kwargs={'sellerpart_id': p1.optimal_seller().id}),
-                                    edit_sellerpart_form_data)
-
+        response = self.client.post(reverse('bom:sellerpart-edit', kwargs={'sellerpart_id': p1.optimal_seller().id}), edit_sellerpart_form_data)
         self.assertEqual(response.status_code, 302)
 
     def test_sellerpart_delete(self):
@@ -1121,6 +1133,16 @@ class TestBOMIntelligent(TestBOM):
         for msg in messages:
             self.assertTrue("This should not happen." not in msg.message, msg=msg.message)
 
+    def test_upload_part_with_sellers(self):
+        # Should pass
+        initial_parts_count = Part.objects.all().count()
+        with open('bom/test_files/test_new_parts_sellers_intelligent.csv') as test_csv:
+            response = self.client.post(reverse('bom:upload-parts'), {'file': test_csv})
+        self.assertEqual(response.status_code, 302)
+
+        parts_count = Part.objects.all().count()
+        self.assertEqual(parts_count - initial_parts_count, 4)
+
     @skip('not applicable')
     def test_upload_part_classes(self):
         pass
@@ -1284,8 +1306,18 @@ class TestForms(TestCase):
             'ncnr': True,
         }
 
-        form = SellerPartForm(organization=self.organization, data=form_data)
-        self.assertTrue(form.is_valid())
+        filled_form = SellerPartForm(form_data, organization=self.organization)
+        self.assertTrue(filled_form.is_valid())
+
+        (p1, p2, p3, p4) = create_some_fake_parts(organization=self.organization)
+        sp = p1.optimal_seller()
+        sp.unit_cost = 10
+        sp.nre_cost = 22
+        sp.save()
+
+        filled_form = SellerPartForm(instance=sp, organization=self.organization)
+        self.assertFalse("$10.0" in filled_form.as_ul())
+        self.assertFalse("$22.0" in filled_form.as_ul())
 
 
 class TestJsonViews(TestCase):
